==> SyL-0.5.0.0.tar.gz: SyL/include/framework/Config/SyL_ConfigActions.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ConfigActions.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륯饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';

/**
 * եɤ߹९饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ConfigActions.php,v 1.2 2006/12/06 13:04:27 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ConfigActions extends SyL_Config
{
    /**
     * ƥʥ̾
     * 
     * @access private
     * @var object
     */
    var $action_name = SYL_CONFIG_ACTION_NAME;
    /**
     * ǥեȼ¹Խ
     * 
     * @param int
     */
    var $default_priority = 5;
    /**
     * ܾ󥪥֥
     * 
     * @access private
     * @var object
     */
    var $forward = null;
    /**
     * ܴ֥
     * 
     * @access private
     * @var object
     */
    var $lc = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param string XMLե̾
     */
    function SyL_ConfigActions($file_name)
    {
        // ƥ饹Υ󥹥ȥ饯
        parent::SyL_Config($file_name);
    }

    /**
     * ȥ򥻥å
     * С饤
     *
     * @access public
     * @param object ȥ饪֥
     */
    function setController(&$controller)
    {
        parent::setController($controller);
        $this->forward =& $controller->container->getComponent('forward');
        $this->lc      =& $controller->container->getComponent('locationmanager');
    }

    /**
     * XMLǡƼϥɥ᥽å
     * С饤
     *
     * @access protected
     * @param string XMLΥѥ
     * @param string XMLΥ°
     * @param string XMLΥ
     */
    function getElement($current_path, $attribute, $text)
    {
        static $name               = '';
        static $component_name     = '';
        static $component_priority = 0;
        static $method_name        = '';
        static $load               = false;

//echo $current_path . "<br>";
        // 1ɺѤߤξʹߥå
        if ($load) return;

        // XMLϷ̤
        switch ($current_path) {
        case '/actions/action':
            if ($name != '') {
                $name = '';
                $load = true;
                return;
            }
            if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                $name = '';
                return;
            }

            // URLǧ
            $reg = isset($attribute['path']) ? $attribute['path'] : '(.*)';
            if (preg_match('|^' . $reg . '$|', $this->forward->getActionFile(), $matches)) {
                $name = $this->action_name;
                $this->config[$name]['class']     = $this->forward->getClassName();
                $this->config[$name]['type']      = 'action';
                $this->config[$name]['file']      = $this->controller->getActionDir() . $this->forward->getActionFile();
                $this->config[$name]['reference'] = true;
                // ¹Խ
                $this->config[$name]['priority'] = $this->default_priority;
                // 󥹥ȥ饯󥸥ե饰
                $this->config[$name]['constructor'] = false;
                // ٥ȥʥ֥Ⱥ
                $this->config[$name]['event'][$this->event][] = $name;
                // 
                $this->config[$name]['args'] = array();

                // ǥեȥƥץ졼ȼ
                $template = $attribute['defaultTemplate'];
                for ($i=0; $i<count($matches); $i++) {
                    $template = str_replace("\${$i}", $matches[$i], $template);
                }
                $this->lc->setTemplateFile($template);

                // ӥ塼饹
                $view_type = isset($attribute['defaultView']) ? $attribute['defaultView'] : 'default';
                $this->lc->setTemplateType($view_type);
                // ޥӥ塼Ƚ
                if (strtolower($view_type) == 'customize') {
                    $this->lc->setCustomizedView($attribute['customizedViewFile'], $attribute['customizedViewClass']);
                }
            } else {
                $name = '';
            }
            break;

        default:
            if (!$name) return;

            switch ($current_path) {
            case '/actions/action/method':
                if (!isset($this->config[$name]['args'])) {
                    $this->config[$name]['args'] = array();
                }
                $method_name = 'method:' . str_replace('{$action}', $this->forward->getActionName(), $attribute['name']);
                $this->config[$name]['args'][$method_name] = array();
                // ٥ȥ
                $this->config[$name]['event'][$this->event][] = $method_name;
                break;

            case '/actions/action/method/arg':
                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                break;

           case '/actions/action/components/component':
                if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                    $component_name = '';
                    return;
                }
                $component_name = $attribute['name'];
                $this->config[$component_name]['class']     = $attribute['class'];
                $this->config[$component_name]['type']      = 'component';
                $this->config[$component_name]['file']      = isset($attribute['file'])   ? $attribute['file']   : '';
                $this->config[$component_name]['reference'] = false;
                // ¹Խ(1ʳᤤ)
                $default_priority = $this->default_priority - 1;
                $component_priority = isset($attribute['priority']) ? floatval($default_priority . '.' . $attribute['priority']) : $default_priority;
                $this->config[$component_name]['priority'] = $component_priority;
                // 󥹥ȥ饯󥸥ե饰
                $this->config[$component_name]['constructor'] = false;
                // ٥ȥ
                $this->config[$component_name]['event'][$this->event][] = $component_name;
                // 
                $this->config[$component_name]['args'] = array();

                // ץꥱ󥳥ݡͥ̾å
                $this->lc->addAppComponent($component_name, '', $component_priority);
                break;

            default:
                if (!$component_name) return;

                switch ($current_path) {
                case '/actions/action/components/component/constructor':
                    $method_name = 'constructor:' . (isset($attribute['static']) ? $attribute['static'] : '');
                    // 󥹥ȥ饯󥸥ե饰
                    $this->config[$component_name]['constructor'] = true;
                    // 󥹥ȥ饯󥸥ξ硢Υ᥽åɤϺ
                    $index = array_search($component_name, $this->config[$component_name]['event'][$this->event]);
                    if ($index !== false) {
                        unset($this->config[$component_name]['event'][$this->event][$index]);
                    }
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/constructor/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/setter':
                    // 쥯ȥåȥ
                    if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
                        $method_name = 'setter:' . $attribute['name'] . ':true';
                    } else {
                        $method_name = 'setter:set' . ucfirst(strtolower($attribute['name'])) . ':false';
                    }
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/setter/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/method':
                    $method_name = 'method:' . $attribute['name'];
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/method/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/final':
                    // ץꥱ󥳥ݡͥ̾å
                    $this->lc->addAppComponent($component_name, $attribute['name'], $component_priority);
                    break;
                }
            }
        }
    }
}

?>

==> SyL-0.5.1.tar.gz: SyL/include/framework/Config/SyL_ConfigActions.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ConfigActions.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ե륯饹
 */
require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';

/**
 * եɤ߹९饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_ConfigActions.php,v 1.3 2006/12/09 08:35:26 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_ConfigActions extends SyL_Config
{
    /**
     * ƥʥ̾
     * 
     * @access private
     * @var object
     */
    var $action_key = SYL_ACTION_KEY;
    /**
     * ǥեȼ¹Խ
     * 
     * @param int
     */
    var $default_priority = 5;
    /**
     * ܾ󥪥֥
     * 
     * @access private
     * @var object
     */
    var $router = null;
    /**
     * ܴ֥
     * 
     * @access private
     * @var object
     */
    var $lc = null;

    /**
     * 󥹥ȥ饯
     *
     * @access public
     * @param string XMLե̾
     */
    function SyL_ConfigActions($file_name)
    {
        // ƥ饹Υ󥹥ȥ饯
        parent::SyL_Config($file_name);
    }

    /**
     * ȥ򥻥å
     * С饤
     *
     * @access public
     * @param object ȥ饪֥
     */
    function setController(&$controller)
    {
        parent::setController($controller);
        $this->router =& $controller->container->getComponent('router');
        $this->lc      =& $controller->container->getComponent('locationmanager');
    }

    /**
     * XMLǡƼϥɥ᥽å
     * С饤
     *
     * @access protected
     * @param string XMLΥѥ
     * @param string XMLΥ°
     * @param string XMLΥ
     */
    function getElement($current_path, $attribute, $text)
    {
        static $name               = '';
        static $component_name     = '';
        static $component_priority = 0;
        static $method_name        = '';
        static $load               = false;

//echo $current_path . "<br>";
        // 1ɺѤߤξʹߥå
        if ($load) return;

        // XMLϷ̤
        switch ($current_path) {
        case '/actions/action':
            if ($name != '') {
                $name = '';
                $load = true;
                return;
            }
            if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                $name = '';
                return;
            }

            // URLǧ
            $reg = isset($attribute['path']) ? $attribute['path'] : '(.*)';
            if (preg_match('|^' . $reg . '$|', $this->router->getActionFile(), $matches)) {
                $name = $this->action_key;
                $this->config[$name]['class']     = $this->router->getClassName();
                $this->config[$name]['type']      = 'action';
                $this->config[$name]['file']      = $this->controller->getActionDir() . $this->router->getActionFile();
                $this->config[$name]['reference'] = true;
                // ¹Խ
                $this->config[$name]['priority'] = $this->default_priority;
                // 󥹥ȥ饯󥸥ե饰
                $this->config[$name]['constructor'] = false;
                // ٥ȥʥ֥Ⱥ
                $this->config[$name]['event'][$this->event][] = $name;
                // 
                $this->config[$name]['args'] = array();

                // ǥեȥƥץ졼ȼ
                $template = $attribute['defaultTemplate'];
                for ($i=0; $i<count($matches); $i++) {
                    $template = str_replace("\${$i}", $matches[$i], $template);
                }
                $this->lc->setTemplateFile($template);

                // ӥ塼饹
                $view_type = isset($attribute['defaultView']) ? $attribute['defaultView'] : 'default';
                $this->lc->setTemplateType($view_type);
                // ޥӥ塼Ƚ
                if (strtolower($view_type) == 'customize') {
                    $this->lc->setCustomizedView($attribute['customizedViewFile'], $attribute['customizedViewClass']);
                }
            } else {
                $name = '';
            }
            break;

        default:
            if (!$name) return;

            switch ($current_path) {
            case '/actions/action/method':
                if (!isset($this->config[$name]['args'])) {
                    $this->config[$name]['args'] = array();
                }
                $method_name = 'method:' . str_replace('{$action}', $this->router->getActionName(), $attribute['name']);
                $this->config[$name]['args'][$method_name] = array();
                // ٥ȥ
                $this->config[$name]['event'][$this->event][] = $method_name;
                break;

            case '/actions/action/method/arg':
                $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                $this->config[$name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                break;

           case '/actions/action/components/component':
                if (isset($attribute['enable']) && ($attribute['enable'] === 'false')) {
                    $component_name = '';
                    return;
                }
                $component_name = $attribute['name'];
                $this->config[$component_name]['class']     = $attribute['class'];
                $this->config[$component_name]['type']      = 'component';
                $this->config[$component_name]['file']      = isset($attribute['file'])   ? $attribute['file']   : '';
                $this->config[$component_name]['reference'] = false;
                // ¹Խ(1ʳᤤ)
                $default_priority = $this->default_priority - 1;
                $component_priority = isset($attribute['priority']) ? floatval($default_priority . '.' . $attribute['priority']) : $default_priority;
                $this->config[$component_name]['priority'] = $component_priority;
                // 󥹥ȥ饯󥸥ե饰
                $this->config[$component_name]['constructor'] = false;
                // ٥ȥ
                $this->config[$component_name]['event'][$this->event][] = $component_name;
                // 
                $this->config[$component_name]['args'] = array();

                // ץꥱ󥳥ݡͥ̾å
                $this->lc->addAppComponent($component_name, '', $component_priority);
                break;

            default:
                if (!$component_name) return;

                switch ($current_path) {
                case '/actions/action/components/component/constructor':
                    $method_name = 'constructor:' . (isset($attribute['static']) ? $attribute['static'] : '');
                    // 󥹥ȥ饯󥸥ե饰
                    $this->config[$component_name]['constructor'] = true;
                    // 󥹥ȥ饯󥸥ξ硢Υ᥽åɤϺ
                    $index = array_search($component_name, $this->config[$component_name]['event'][$this->event]);
                    if ($index !== false) {
                        unset($this->config[$component_name]['event'][$this->event][$index]);
                    }
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/constructor/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/setter':
                    // 쥯ȥåȥ
                    if (isset($attribute['direct']) && ($attribute['direct'] === 'true')) {
                        $method_name = 'setter:' . $attribute['name'] . ':true';
                    } else {
                        $method_name = 'setter:set' . ucfirst(strtolower($attribute['name'])) . ':false';
                    }
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/setter/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/method':
                    $method_name = 'method:' . $attribute['name'];
                    $this->config[$component_name]['event'][$this->event][] = $method_name;
                    $this->config[$component_name]['args'][$method_name] = array();
                    break;

                case '/actions/action/components/component/method/arg':
                    $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                    $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                    $this->config[$component_name]['args'][$method_name][] = $type . ':' . $ref . ':' . $text;
                    break;

                case '/actions/action/components/component/final':
                    // ץꥱ󥳥ݡͥ̾å
                    $this->lc->addAppComponent($component_name, $attribute['name'], $component_priority);
                    break;
                }
            }
        }
    }
}

?>
